@@ -16,10 +16,13 @@ from .sequence_classification import (
 from .question_answering import EasyQuestionAnswering, TransformersQuestionAnswering
 from .summarization import EasySummarizer, TransformersSummarizer
 from .translation import EasyTranslator, TransformersTranslator
+from .text_generation import EasyTextGenerator, TransformersTextGenerator
+from .language_model import LMFineTuner
 
 # Training and Fine-tuning Modules
+# TODO: Deprecating in 0.3.0+
 from .training import SequenceClassifierTrainer
-from .transformers.finetuning import LMFineTuner
+from .transformers.finetuning import LMFineTunerManual
 
 # global variable like flair's: cache_root
 cache_root = Path(Path.home(), ".adaptnlp")
@@ -43,6 +46,9 @@ __all__ = [
     "TransformersSummarizer",
     "EasyTranslator",
     "TransformersTranslator",
+    "EasyTextGenerator",
+    "TransformersTextGenerator",
     "SequenceClassifierTrainer",
     "LMFineTuner",
+    "LMFineTunerManual",
 ]
